@@ -1,10 +1,10 @@
 package App::hr;
 
-our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-07-06'; # DATE
+our $VERSION = '0.12'; # VERSION
 
-use 5.010001;
-use strict;
+use feature 'say';
+use strict 'subs', 'vars';
 use warnings;
 
 use Exporter;
@@ -15,10 +15,13 @@ our @EXPORT_OK = qw(
 
 our %SPEC;
 
-sub pick {
-    return undef unless @_;
-    return $_[@_*rand];
-}
+# IFBUILT
+## INSERT_BLOCK_FROM_MODULE: Code::Embeddable pick
+# END IFBUILT
+# IFUNBUILT
+use Code::Embeddable; *pick = \&Code::Embeddable::pick;
+# END IFUNBUILT
+
 
 my $term_width;
 if (eval { require Term::Size; 1 }) {
@@ -105,6 +108,7 @@ _
             },
         },
     },
+    'cmdline.skip_format' => 1,
 };
 sub hr_app {
     my %args = @_;
@@ -149,7 +153,7 @@ sub hr_app {
 
     my $res = hr($args{pattern}, $args{color});
 
-    [200, "OK", $res, {'cmdline.skip_format' => 1}];
+    [200, "OK", $res];
 }
 
 1;
@@ -167,7 +171,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.11 of App::hr (from Perl distribution App-hr), released on 2015-07-02.
+This document describes version 0.12 of App::hr (from Perl distribution App-hr), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
@@ -188,7 +192,7 @@ You can also use the provided CLI L<hr>.
 
 =for Pod::Coverage ^(pick)$
 
-=head1 FUNCTIONS_TMP
+=head1 FUNCTIONS
 
 =head2 hr([PATTERN]) => optional STR
 
@@ -205,8 +209,6 @@ Terminal width is currently determined using L<Term::App::Role::Attrs>, which
 will either use environment variable C<COLUMNS> or detecting using
 L<Term::Size>, or if all those fail, use a hard-coded default of 80.
 
-=head1 FUNCTIONS
-
 
 =head2 hr_app(%args) -> [status, msg, result, meta]
 
@@ -268,7 +270,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-hr>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-hr>.
+Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Term-Util>.
 
 =head1 BUGS
 
